---
name: Bug report
about: Let us know about a bug you have found in Crow
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
Please provide a clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to PrePull
2. Select these data files (include them)
3. In config.yaml, choose a resolution of...
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. Windows 10]
 - Version [e.g. 1.1.0]

**Additional context**
Add any other context about the problem here.
